package com.nokia.financeapi.controller.car;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.pojo.dto.GetCarMapStatDto;
import com.nokia.financeapi.pojo.dto.GetCarNoticeDto;
import com.nokia.financeapi.pojo.dto.GetCarTypeStatDto;
import com.nokia.financeapi.pojo.vo.GetCarMapStatVo;
import com.nokia.financeapi.pojo.vo.GetCarNoticeVo;
import com.nokia.financeapi.pojo.vo.GetCarTypeStatVo;
import com.nokia.financeapi.service.car.CarResourceMapService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

@Tag(name = "车辆资源地图")
@RestController
@RequestMapping("/house-car/car/resource-map/api")
public class CarResourceMapController {
    private final CarResourceMapService carResourceMapService;

    public CarResourceMapController(CarResourceMapService carResourceMapService) {
        this.carResourceMapService = carResourceMapService;
    }

    @Operation(summary = "获取公告列表")
    @PostMapping("/getNotice")
    public R<List<GetCarNoticeVo>> getNotice(@Valid @RequestBody GetCarNoticeDto dto) {
        return carResourceMapService.getNotice(dto);
    }

    @Operation(summary = "获取车辆类型统计")
    @PostMapping("/getCarTypeStat")
    public R<GetCarTypeStatVo> getCarTypeStat(@Valid @RequestBody GetCarTypeStatDto dto) {
        return carResourceMapService.getCarTypeStat(dto);
    }

    @Operation(summary = "获取车辆地图统计")
    @PostMapping("/getCarMapStat")
    public R<List<GetCarMapStatVo>> getCarMapStat(@Valid @RequestBody GetCarMapStatDto dto) {
        return carResourceMapService.getCarMapStat(dto);
    }
}
